@@ -9,7 +9,7 @@
 // Название языковой модели
 #define ANYKS_LM_NAME "alm"
 // Версия приложения
-#define ANYKS_LM_VERSION "3.1.1"
+#define ANYKS_LM_VERSION "3.1.4"
 // Автор приложения
 #define ANYKS_LM_AUTHOR "Yuriy Lobarev"
 // Телефон автора
@@ -22,6 +22,8 @@
 #define ANYKS_LM_SITE "https://anyks.com"
 
 /** ПАРАМЕТРЫ СЛОВ **/
+// Локаль словаря по умолчанию
+#define ALPHABET_LOCALE "en_US.UTF-8"
 // Максимальная длина последовательности в символах
 #define MAX_SEQ_LENGTH 50
 // Максимальная длина слова
