@@ -17,6 +17,7 @@
 #include <ctime>
 #include <regex>
 #include <atomic>
+#include <vector>
 /**
  * Наши модули
  */
@@ -100,11 +101,24 @@ namespace anyks {
 			const long getSize(const string & str) const noexcept;
 			/**
 			 * train Обучения полученного текста
-			 * @param filename адрес файла для сохранения (без расширения)
-			 * @param text     список строк текста для обучения
+			 * @param dest      адрес каталога для сохранения
+			 * @param filenames список файлов для обучения
+			 */
+			void train(const string & dest, const vector <string> & filenames) noexcept;
+			/**
+			 * train Обучения полученного текста
+			 * @param dest     адрес каталога для сохранения
+			 * @param filename файл для чтения
 			 * @param idd      идентификатор документа
 			 */
-			void train(const string & filename, const list <string> & text, const size_t idd) noexcept;
+			void train(const string & dest, const string & filename, const size_t idd) noexcept;
+			/**
+			 * train Обучения полученного текста
+			 * @param dest адрес каталога для сохранения
+			 * @param text список строк текста для обучения
+			 * @param idd  идентификатор документа
+			 */
+			void train(const string & dest, const vector <string> & text, const size_t idd) noexcept;
 		public:
 			/**
 			 * setOrder Метод установки размер n-граммы
