@@ -276,6 +276,37 @@ namespace anyks {
 		}
 // Если это clang v10 или выше
 #if defined(__ANYKS_EXPERIMENTAL__)
+		/**
+		 * fcount Функция подсчёта количество файлов в каталоге
+		 * @param path путь для подсчёта
+		 * @param ext  расширение файла по которому идет фильтрация
+		 * @return     количество файлов в каталоге
+		 */
+		static const uintmax_t fcount(const string & path, const string & ext) noexcept {
+			// Результат работы функции
+			uintmax_t result = 0;
+			// Если адрес каталога и расширение файлов переданы
+			if(!path.empty() && !ext.empty() && isdir(path)){
+				// Устанавливаем область видимости
+				namespace fs = std::__fs::filesystem;
+				// Устанавливаем путь поиска
+				fs::path dirpath = path;
+				// Выполняем рекурсивный переход по всем подкаталогам
+				for(auto && entry : fs::recursive_directory_iterator(dirpath, fs::directory_options::skip_permission_denied)){
+					// Возможная ошибка
+					error_code ignore_error;
+					// Запрашиваем файл из каталога и считаем его размер
+					if(fs::is_regular_file(fs::symlink_status(entry, ignore_error))){
+						// Получаем путь файла
+						fs::path fsp = entry.path();
+						// Если расширение файла соответствует
+						if(string(fsp.extension().c_str()).rfind(ext) != string::npos) result++;
+					}
+				}
+			}
+			// Выводим результат
+			return result;
+		}
 		/**
 		 * dsize Функция подсчёта размера каталога
 		 * @param path путь для подсчёта
@@ -309,6 +340,58 @@ namespace anyks {
 		}
 // Если это gcc
 #else
+		/**
+		 * fcount Функция подсчёта количество файлов в каталоге
+		 * @param path путь для подсчёта
+		 * @param ext  расширение файла по которому идет фильтрация
+		 * @return     количество файлов в каталоге
+		 */
+		static const uintmax_t fcount(const string & path, const string & ext) noexcept {
+			// Результат работы функции
+			uintmax_t result = 0;
+			// Если адрес каталога и расширение файлов переданы
+			if(!path.empty() && !ext.empty() && isdir(path)){
+				// Открываем указанный каталог
+				DIR * dir = opendir(path.c_str());
+				// Если каталог открыт
+				if(dir != nullptr){
+					// Структура проверка статистики
+					struct stat info;
+					// Создаём объект алфавита
+					alphabet_t alphabet;
+					// Создаем указатель на содержимое каталога
+					struct dirent * ptr = nullptr;
+					// Выполняем чтение содержимого каталога
+					while((ptr = readdir(dir))){
+						// Пропускаем названия текущие "." и внешние "..", так как идет рекурсия
+						if(!strcmp(ptr->d_name, ".") || !strcmp(ptr->d_name, "..")) continue;
+						// Получаем адрес в виде строки
+						const string & address = alphabet.format("%s/%s", path.c_str(), ptr->d_name);
+						// Если статистика извлечена
+						if(!stat(address.c_str(), &info)){
+							// Если дочерний элемент является дирректорией
+							if(S_ISDIR(info.st_mode)) result += dsize(address, ext);
+							// Если дочерний элемент является файлом то удаляем его
+							else {
+								// Получаем расширение файла
+								const string & extension = alphabet.format(".%s", ext.c_str());
+								// Получаем длину адреса
+								const size_t length = extension.length();
+								// Если расширение файла найдено
+								if(address.substr(address.length() - length, length).compare(extension) == 0){
+									// Получаем количество файлов в каталоге
+									result++;
+								}
+							}
+						}
+					}
+					// Закрываем открытый каталог
+					closedir(dir);
+				}
+			}
+			// Выводим результат
+			return result;
+		}
 		/**
 		 * dsize Функция подсчёта размера каталога
 		 * @param path путь для подсчёта
@@ -466,6 +549,72 @@ namespace anyks {
 				} else cerr << "error: the file name: \"" << filename << "\" is not found" << endl;
 			}
 		}
+		/**
+		 * rfile2 Функция рекурсивного получения всех строк файла (стандартным способом)
+		 * @param filename адрес файла для чтения
+		 * @param callback функция обратного вызова
+		 */
+		static void rfile2(const string & filename, function <void (const string &, const uintmax_t)> callback) noexcept {
+			// Если адрес файла передан
+			if(!filename.empty()){
+				// Если файл существует
+				if(isfile(filename)){
+					// Открываем файл на чтение
+					ifstream file(filename, ios::in);
+					// Если файл открыт
+					if(file.is_open()){
+						// Перемещаем указатель в конец файла
+						file.seekg(0, file.end);
+						// Определяем размер файла
+						const size_t size = file.tellg();
+						// Возвращаем указатель обратно
+						file.seekg(0, file.beg);
+						// Устанавливаем размер буфера
+						vector <char> buffer(size);
+						// Выполняем чтение данных из файла
+						file.read(buffer.data(), size);
+						// Устанавливаем буфер
+						if(!buffer.empty()){
+							// Значение текущей и предыдущей буквы
+							char letter = 0, old = 0;
+							// Смещение в буфере и длина полученной строки
+							size_t offset = 0, length = 0;
+							// Получаем данные буфера
+							const char * data = buffer.data();
+							// Получаем размер файла
+							const uintmax_t size = buffer.size();
+							// Переходим по всему буферу
+							for(uintmax_t i = 0; i < size; i++){
+								// Получаем значение текущей буквы
+								letter = reinterpret_cast <const char *> (data)[i];
+								// Если текущая буква является переносом строк
+								if((i > 0) && ((letter == '\n') || (i == (size - 1)))){
+									// Если предыдущая буква была возвратом каретки, уменьшаем длину строки
+									length = ((old == '\r' ? i - 1 : i) - offset);
+									// Если это конец файла, корректируем размер последнего байта
+									if(length == 0) length = 1;
+									// Если длина слова получена, выводим полученную строку
+									callback(string((char *) data + offset, length), size);
+									// Выполняем смещение
+									offset = (i + 1);
+								}
+								// Запоминаем предыдущую букву
+								old = letter;
+							}
+							// Если данные не все прочитаны, выводим как есть
+							if((offset == 0) && (size > 0)) callback(string((char *) data, size), size);
+							// Очищаем буфер данных
+							buffer.clear();
+							// Освобождаем выделенную память
+							vector <char> ().swap(buffer);
+						}
+						// Закрываем файл
+						file.close();
+					}
+				// Выводим сообщение об ошибке
+				} else cerr << "error: the file name: \"" << filename << "\" is not found" << endl;
+			}
+		}
 // Если это clang v10 или выше
 #if defined(__ANYKS_EXPERIMENTAL__)
 		/**
@@ -563,6 +712,26 @@ namespace anyks {
 			} else cerr << "error: the path name: \"" << path << "\" is not found" << endl;
 		}
 #endif
+		/**
+		 * rfdir Функция рекурсивного чтения файлов во всех подкаталогах
+		 * @param path     путь до каталога
+		 * @param ext      расширение файла по которому идет фильтрация
+		 * @param callback функция обратного вызова
+		 */
+		static void rfdir(const string & path, const string & ext, function <void (const string &, const string &, const uintmax_t, const uintmax_t)> callback) noexcept {
+			// Если адрес каталога и расширение файлов переданы
+			if(!path.empty() && !ext.empty() && isdir(path)){
+				// Переходим по всему списку файлов в каталоге
+				rdir(path, ext, [&](const string & filename, const uintmax_t dirSize) noexcept {
+					// Выполняем считывание всех строк текста
+					rfile2(filename, [&](const string & str, const uintmax_t fileSize) noexcept {
+						// Если текст получен
+						if(!str.empty()) callback(str, filename, fileSize, dirSize);
+					});
+				});
+			// Выводим сообщение об ошибке
+			} else cerr << "error: the path name: \"" << path << "\" is not found" << endl;
+		}
 	} fsys_t;
 };
 
