@@ -8,7 +8,6 @@
 
 #include <alphabet.hpp>
 
-
 // Устанавливаем шаблон функции
 template <typename T>
 /**
@@ -208,14 +207,12 @@ const char anyks::Alphabet::toLower(const char letter) const noexcept {
 	if(letter > 0){
 		// Строка для конвертации
 		wstring str = L"";
-		// Объявляем конвертер
-		wstring_convert <codecvt_utf8 <wchar_t>> conv;
 		// Выполняем конвертирование в utf-8 строку
-		const wchar_t c = conv.from_bytes({1, letter}).front();
+		const wchar_t c = this->convert(string{1, letter}).front();
 		// Формируем новую строку
 		str.assign(1, towlower(c));
 		// Выполняем конвертирование в utf-8 строку
-		result = conv.to_bytes(str).front();
+		result = this->convert(str).front();
 	}
 	// Выводим результат
 	return result;
@@ -232,14 +229,12 @@ const char anyks::Alphabet::toUpper(const char letter) const noexcept {
 	if(letter > 0){
 		// Строка для конвертации
 		wstring str = L"";
-		// Объявляем конвертер
-		wstring_convert <codecvt_utf8 <wchar_t>> conv;
 		// Выполняем конвертирование в utf-8 строку
-		const wchar_t c = conv.from_bytes({1, letter}).front();
+		const wchar_t c = this->convert(string{1, letter}).front();
 		// Формируем новую строку
 		str.assign(1, towupper(c));
 		// Выполняем конвертирование в utf-8 строку
-		result = conv.to_bytes(str).front();
+		result = this->convert(str).front();
 	}
 	// Выводим результат
 	return result;
@@ -670,9 +665,7 @@ const bool anyks::Alphabet::isUrl(const wstring & word) const noexcept {
 	// Если слово передано
 	if(!word.empty()){
 		// Выполняем парсинг uri адреса
-		this->uri.parse(word);
-		// Извлекаем данные uri адреса
-		auto resUri = this->uri.get();
+		auto resUri = this->uri.parse(word);
 		// Если ссылка найдена
 		result = ((resUri.type != uri_t::types_t::null) && (resUri.type != uri_t::types_t::wrong));
 	}
@@ -1420,9 +1413,7 @@ const std::map <size_t, size_t> anyks::Alphabet::urls(const wstring & text) cons
 		// Выполням поиск ссылок в тексте
 		while(pos < text.length()){
 			// Выполняем парсинг uri адреса
-			this->uri.parse(text.substr(pos));
-			// Извлекаем данные uri адреса
-			auto resUri = this->uri.get();
+			auto resUri = this->uri.parse(text.substr(pos));
 			// Если ссылка найдена
 			if(resUri.type != uri_t::types_t::null){
 				// Получаем данные слова
@@ -1704,6 +1695,8 @@ void anyks::Alphabet::setlocale(const string & locale) noexcept {
 		// Устанавливапм локализацию приложения
 		::setlocale(LC_CTYPE, locale.c_str());
 		::setlocale(LC_COLLATE, locale.c_str());
+		// Устанавливаем локаль системы
+		this->locale = std::locale(locale.c_str());
 	}
 }
 /**
