@@ -83,6 +83,20 @@ namespace anyks {
 	 * Methods Основные методы библиотеки
 	 */
 	namespace Methods {
+		/**
+		 * allowStress Метод разрешения, использовать ударение в словах
+		 */
+		void allowStress() noexcept {
+			// Разрешаем использовать ударение в словах
+			tokenizer.allowStress();
+		}
+		/**
+		 * disallowStress Метод запрещения использовать ударение в словах
+		 */
+		void disallowStress() noexcept {
+			// Запрещаем использовать ударение в словах
+			tokenizer.disallowStress();
+		}
 		/**
 		 * idt Метод извлечения идентификатора токена
 		 * @param  word слово для получения идентификатора
@@ -1278,6 +1292,8 @@ PYBIND11_MODULE(alm, m) {
 		.def("pplConcatenate", &anyks::Methods::pplConcatenate, "Method of combining perplexia")
 		// getUserTokens Метод извлечения списка пользовательских токенов
 		.def("getUserTokens", &anyks::Methods::getUserTokens, "User token list retrieval method")
+		// allowStress Метод разрешения, использовать ударение в словах
+		.def("allowStress", &anyks::Methods::allowStress, "Method for allow using stress in words")
 		// tokenization Метод разбивки текста на токены
 		.def("tokenization", &anyks::Methods::tokenization, "Method for breaking text into tokens")
 		// fixUppers Метод исправления регистров в тексте
@@ -1296,6 +1312,8 @@ PYBIND11_MODULE(alm, m) {
 		.def("getVersion", &anyks::Methods::getVersion, "Method for obtaining the language model version")
 		// isAllowApostrophe Метод проверки разрешения апострофа
 		.def("isAllowApostrophe", &anyks::Methods::isAllowApostrophe, "Apostrophe permission check method")
+		// disallowStress Метод запрещения использовать ударение в словах
+		.def("disallowStress", &anyks::Methods::disallowStress, "Method for disallow using stress in words")
 		// getUserTokenId Метод получения идентификатора пользовательского токена
 		.def("getUserTokenId", &anyks::Methods::getUserTokenId, "Method for obtaining user token identifier")
 		// roman2Arabic Метод перевода римских цифр в арабские
@@ -1409,7 +1427,7 @@ PYBIND11_MODULE(alm, m) {
 		// checkSequence Метод проверки существования последовательности
 		.def("checkSequence", overload_cast_ <const vector <size_t> &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <size_t> (), py::arg("accurate") = false)
 		// checkSequence Метод проверки существования последовательности
-		.def("checkSequence", overload_cast_ <const vector <wstring> &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <wstring> (), py::arg("accurate") = false)
+		.def("checkSequence", overload_cast_ <const vector <size_t> &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <wstring> (), py::arg("accurate") = false)
 		// countsByFiles Метод подсчёта количества n-грамм в текстовом файле
 		.def("countsByFiles", &anyks::Methods::countsByFiles, "Method for counting the number of n-grams in a text file", py::arg("path") = L"", py::arg("filename") = L"", py::arg("ngrams") = 0, py::arg("ext") = L"txt")
 		// checkByFiles Метод проверки существования последовательности в текстовом файле
